@charset "UTF-8";

body {
	margin: 0;
	padding: 0;
	word-break: break-all;
	font-family: sans-serif;
	background: #FCFCFC;
}

#menu {
	position: relative;
	padding: .5em 5px;
	font-size: 12px;
	line-height: 1.2;
	border-bottom: 1px solid #8499AE;
	background: #FFF;
}

#menu .keyword_recent_notice {
	position: absolute;
	right: 0;
	bottom: 0;
	z-index: 10;
	background: none;
}

#menu .keyword_recent_notice a:link {
	color: #F33;
}

#menu .channel {
	display: inline;
	font-size: 100%;
	z-index: 100;
}

#menu a {
	text-decoration:none;
}

#menu .channel a:link {
	color: #666;
}

#menu .unread a:link {
	font-size: 167%;
	font-weight: bold;
	color: #0080FF;
}

#menu .KeywordChannel a:link {
	font-size: 167%;
	font-weight: bold;
	color: #933;
}

form {
	margin: 0;
	text-align: center;
	padding: .5em 0;
	border-top: 1px solid #FFF;
	border-bottom: 1px solid #8499AE;
}

form input[type="text"] {
	width: 70%;
	height: 2em;
}

form input[type="button"] {
	width: 20%;
	height: 2.5em;
}

#contents {
	margin: 0;
	padding: .5em 5px;
	border-bottom: 1px solid #8499AE;
	line-height: 1.5;
	background: #FFF;
}

#contents:empty {
	padding: 0;
	border-bottom: none;
}

#footer {
	padding: .3em 5px;
	text-align: center;
	font-size: 10px;
	color: #666;
	border-top: 1px solid #FFF;
}
